# Traductor

Programa para traducir palabras de Ingles a Español.

## Instalación

Desde testpypi
~~~
pip install ..... 
~~~


Desde pypi
~~~
pip install traductorsqb
~~~

## Forma de uso

~~~
traductorsqb "hello"
hello -> hola
~~~